<?php

/**
 * @file
 * Contains \Drupal\couchbasedrupal\Cache\CouchbaseRawBackendFactory.
 */

namespace Drupal\couchbasedrupal\Cache;

use Drupal\couchbasedrupal\CouchbaseManager;

use Drupal\Core\Site\Settings;
use Drupal\Core\Cache\CacheFactoryInterface;

class CouchbaseRawBackendFactory implements CacheFactoryInterface {

  /**
   * Couchbase manager service.
   * 
   * @var CouchbaseManager
   */
  protected $couchbaseManager;

  /**
   * The cache tags checksum provider.
   *
   * @var string
   */
  protected $sitePrefix;

  /**
   * Constructs the WincacheRawBackendFactory
   * 
   * @param string $root
   *   The site's root.
   * @param string $site_path 
   *   The site's path.
   */
  function __construct(CouchbaseManager $manager, $root, $site_path) {
    $this->couchbaseManager = $manager;
    // We need shorter and more readable prefixes.
    $this->sitePrefix = substr(base_convert(md5(Settings::getApcuPrefix('apc_backend', $root, $site_path)), 16,32), 0, 12);
  }

  /**
   * Gets DatabaseBackend for the specified cache bin.
   *
   * @param $bin
   *   The cache bin for which the object is created.
   *
   * @return CouchbaseRawBackend
   *   The cache backend object for the specified cache bin.
   */
  function get($bin) {
    $bucket = $this->couchbaseManager->getBucket('default', 'default');
    return new CouchbaseRawBackend($this->sitePrefix . ':' . $bin . ':', $bucket);
  }

}
