<?php

namespace Drupal\couchbasedrupal;

use Drupal\Core\DependencyInjection\ServiceModifierInterface;
use Drupal\Core\DependencyInjection\ServiceProviderInterface;
use Drupal\Core\DependencyInjection\ContainerBuilder;

use Drupal\Core\Site\Settings;

use Drupal\couchbasedrupal\Cache\CouchbaseBackendFactory;
use Drupal\couchbasedrupal\Cache\CouchbaseTagsChecksum;
use Drupal\couchbasedrupal\Lock\CouchbaseLockBackend;
use Drupal\Core\Lock\DatabaseLockBackend;
use Drupal\Core\Lock\PersistentDatabaseLockBackend;
use Drupal\Core\Cache\DatabaseCacheTagsChecksum;

class CouchbasedrupalServiceProvider implements ServiceProviderInterface {
  /**
   * {@inheritdoc}
   */
  public function register(ContainerBuilder $container) {
    // Set chained fast backend persitent storage
    if ($container->has('cache.backend.chainedfast')) {
      $definition  = $container->getDefinition('cache.backend.chainedfast');
      $args = $definition->getArguments();
      // Add the missins optional arguments
      if (!isset($args[1])) {
        $args[] = 'cache.backend.couchbase';
        $definition->setArguments($args);
      }
    }

    // Set chained fast backend persitent storage
    if ($container->has('cache.backend.superchainedfast')) {
      $definition  = $container->getDefinition('cache.backend.superchainedfast');
      $args = $definition->getArguments();
      // Add the missins optional arguments
      if (!isset($args[1])) {
        $args[] = 'cache.backend.couchbase';
        $definition->setArguments($args);
      }
    }

    // Set chained fast backend persitent storage
    if ($container->has('cache.rawbackend.chainedfast')) {
      $definition  = $container->getDefinition('cache.rawbackend.chainedfast');
      $args = $definition->getArguments();
      // Add the missins optional arguments
      if (!isset($args[1])) {
        $args[] = 'cache.rawbackend.couchbase';
        $definition->setArguments($args);
      }
    }

    // Override tag checksum invalidator
    // Do not replace this, because the CacheCacheTagInvalidator
    // from supercache is much better, and still uses couchbase in behind.
    //$definition = $container->getDefinition('cache_tags.invalidator.checksum');
    //if ($definition->getClass() == DatabaseCacheTagsChecksum::class) {
    //  $couchbase_definition = $container->getDefinition('cache_tags.invalidator.checksum.couchbase');
    //  $definition->setClass($couchbase_definition->getClass());
    //  $definition->setArguments($couchbase_definition->getArguments());
    //}

    // Override locking backend.
    $definition = $container->getDefinition('lock');
    if ($definition->getClass() == DatabaseLockBackend::class) {
      $couchbase_definition = $container->getDefinition('lock.couchbase');
      $definition->setClass($couchbase_definition->getClass());
      $definition->setArguments($couchbase_definition->getArguments());
    }

    // Override persistent locking backend.
    $definition = $container->getDefinition('lock.persistent');
    if ($definition->getClass() == PersistentDatabaseLockBackend::class) {
      $couchbase_definition = $container->getDefinition('lock.persistent.couchbase');
      $definition->setClass($couchbase_definition->getClass());
      $definition->setArguments($couchbase_definition->getArguments());
    }

  }
}
